# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import codenerix.fields
import codenerix.lib.helpers


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CorporateImage',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('digital_sign', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, null=True, verbose_name='Digital sign', blank=True)),
                ('company_seal', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, null=True, verbose_name='Company seal', blank=True)),
                ('company_logo', codenerix.fields.ImageAngularField(max_length=200, upload_to=codenerix.lib.helpers.upload_path, null=True, verbose_name='Company logo', blank=True)),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
            ],
            options={
                'permissions': [('list_corporateimage', 'Can list corporateimage'), ('detail_corporateimage', 'Can view corporateimage')],
            },
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-corporate
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.db import models, transaction
from django.utils.translation import ugettext_lazy as _

from codenerix.models import CodenerixModel
from codenerix.exceptions import CodenerixException
from codenerix.lib.helpers import upload_path
from codenerix.fields import ImageAngularField


class CorporateImage(CodenerixModel):

    nid = models.CharField(_("NID"), max_length=20, blank=True)
    business_name = models.CharField(_("Business name"), max_length=254, blank=True, null=True)
    digital_sign = ImageAngularField(_("Digital sign"), upload_to=upload_path, max_length=200, blank=True, null=True)
    name_file_sign = models.CharField(_("Name file digital sign"), max_length=254, blank=True, null=True)
    company_seal = ImageAngularField(_("Company seal"), upload_to=upload_path, max_length=200, blank=True, null=True)
    name_file_seal = models.CharField(_("Name file company seal"), max_length=254, blank=True, null=True)
    company_logo = ImageAngularField(_("Company logo"), upload_to=upload_path, max_length=200, blank=True, null=True)
    name_file_logo = models.CharField(_("Name file company logo"), max_length=254, blank=True, null=True)
    public = models.BooleanField(_("Public"), default=False)

    def __unicode__(self):
        return self.__str__()

    def __str__(self):
        return u"{}".format(self.business_name)

    def __fields__(self, info):
        fields = []
        fields.append(('nid', _('NID'), 100))
        fields.append(('business_name', _('Business name'), 100))
        fields.append(('digital_sign', _('Digital sign'), 15))
        fields.append(('name_file_sign', _('Name file digital sign'), 15))
        fields.append(('company_seal', _('Company seal'), 15))
        fields.append(('name_file_seal', _('Name file company seal'), 15))
        fields.append(('company_logo', _('Company logo'), 15))
        fields.append(('name_file_logo', _('Name file company logo'), 15))
        fields.append(('public', _('Public'), 100))
        fields.append(('updated', _('Last Update'), 100))
        return fields

    def save(self, *args, **kwards):
        """
        Siempre debe haber un registro marcado como público
        There should always be a record marked as public
        """
        try:
            with transaction.atomic():
                if self.public:
                    CorporateImage.objects.exclude(pk=self.pk).update(public=False)
                elif not CorporateImage.objects.exclude(pk=self.pk).filter(public=True).exists():
                    self.public = True

                return super(CorporateImage, self).save(*args, **kwards)
        except CodenerixException:
            return super(CorporateImage, self).save(*args, **kwards)



# -*- coding: utf-8 -*-
#
# django-codenerix-corporate
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.utils.translation import ugettext_lazy as _
from codenerix.forms import GenModelForm
from codenerix_corporate.models import CorporateImage


class CorporateImageForm(GenModelForm):
    class Meta:
        model = CorporateImage
        exclude = ['name_file_sign', 'name_file_seal', 'name_file_logo', ]

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['business_name', 6],
                ['nid', 4],
                ['public', 2],
                ['digital_sign', 4],
                ['company_seal', 4],
                ['company_logo', 4],
            )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['business_name', 6],
                ['nid', 4],
                ['digital_sign', 6],
                ['name_file_sign', 6],
                ['company_seal', 6],
                ['name_file_seal', 6],
                ['company_logo', 6],
                ['name_file_logo', 6],
                ['public', 6],)
        ]
        return g



# -*- coding: utf-8 -*-
#
# django-codenerix-corporate
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import json

from django.utils.translation import ugettext as _
from codenerix.views import GenList, GenCreate, GenCreateModal, GenUpdate, GenUpdateModal, GenDelete

from codenerix_corporate.models import CorporateImage
from codenerix_corporate.forms import CorporateImageForm


# ###########################################
# Corporate Image
class CorporateImageList(GenList):
    model = CorporateImage
    default_ordering = ['-public', ]
    extra_context = {'menu': ['CDNX_CorporateImage', 'CDNX_CorporateImage'], 'bread': [_('CorporateImage'), _('CorporateImage')]}
    gentranslate = {
        'image_not_selected': _("Image not selected")
    }


class CorporateImageCreate(GenCreate):
    model = CorporateImage
    form_class = CorporateImageForm

    def form_valid(self, form):
        # Get body
        body = json.loads(self.request.body.decode('utf-8'))

        # Get digital_sign
        digital_sign = body.get('digital_sign', None)
        if isinstance(digital_sign, dict):
            name_file_sign = digital_sign.get('filename', None)
            if name_file_sign is not None:
                self.request.name_file_sign = name_file_sign
                form.instance.name_file_sign = name_file_sign

        # Get company seal
        company_seal = body.get('company_seal', None)
        if isinstance(company_seal, dict):
            name_file_seal = company_seal.get('filename', None)
            if name_file_seal is not None:
                self.request.name_file_seal = name_file_seal
                form.instance.name_file_seal = name_file_seal

        # Get company logo
        company_logo = body.get('company_logo', None)
        if isinstance(company_logo, dict):
            name_file_logo = company_logo.get('filename', None)
            if name_file_logo is not None:
                self.request.name_file_logo = name_file_logo
                form.instance.name_file_logo = name_file_logo

        # Return result
        return super(CorporateImageCreate, self).form_valid(form)


class CorporateImageCreateModal(GenCreateModal, CorporateImageCreate):
    pass


class CorporateImageUpdate(GenUpdate):
    model = CorporateImage
    form_class = CorporateImageForm

    def form_valid(self, form):
        # Get body
        body = json.loads(self.request.body.decode('utf-8'))

        # Get digital_sign
        digital_sign = body.get('digital_sign', None)
        if isinstance(digital_sign, dict):
            name_file_sign = digital_sign.get('filename', None)
            if name_file_sign is not None:
                self.request.name_file_sign = name_file_sign
                form.instance.name_file_sign = name_file_sign

        # Get company seal
        company_seal = body.get('company_seal', None)
        if isinstance(company_seal, dict):
            name_file_seal = company_seal.get('filename', None)
            if name_file_seal is not None:
                self.request.name_file_seal = name_file_seal
                form.instance.name_file_seal = name_file_seal

        # Get company logo
        company_logo = body.get('company_logo', None)
        if isinstance(company_logo, dict):
            name_file_logo = company_logo.get('filename', None)
            if name_file_logo is not None:
                self.request.name_file_logo = name_file_logo
                form.instance.name_file_logo = name_file_logo

        # Return result
        return super(CorporateImageUpdate, self).form_valid(form)


class CorporateImageUpdateModal(CorporateImageUpdate, GenUpdateModal):
    pass


class CorporateImageDelete(GenDelete):
    model = CorporateImage



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-07-24 08:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_corporate', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='corporateimage',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='business_name',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Business name'),
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='name_file_logo',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name file company logo'),
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='name_file_seal',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name file company seal'),
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='name_file_sign',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name file digital sign'),
        ),
        migrations.AddField(
            model_name='corporateimage',
            name='nid',
            field=models.CharField(blank=True, max_length=20, verbose_name='NID'),
        ),
    ]
